@@ -2,6 +2,8 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = 'giswqs@gmail.com'
-__version__ = '0.5.0'
+__version__ = '0.6.9'
 
-from .geemap import *
\ No newline at end of file
+from .geemap import *
+from .basemaps import ee_basemaps
+from .legends import builtin_legends
\ No newline at end of file
